* [benchmark-program](benchmark-program/index.md)
* [compile-program](compile-program/index.md)
* [convert-csv-to-md](convert-csv-to-md/index.md)
* [copy-to-clipboard](copy-to-clipboard/index.md)
* [create-conda-env](create-conda-env/index.md)
* [create-patch](create-patch/index.md)
* [detect-sudo](detect-sudo/index.md)
* [download-and-extract](download-and-extract/index.md)
* [download-file](download-file/index.md)
* [download-torrent](download-torrent/index.md)
* [extract-file](extract-file/index.md)
* [fail](fail/index.md)
* [get-conda](get-conda/index.md)
* [get-git-repo](get-git-repo/index.md)
* [get-github-cli](get-github-cli/index.md)
* [pull-git-repo](pull-git-repo/index.md)
* [push-csv-to-spreadsheet](push-csv-to-spreadsheet/index.md)
* [set-device-settings-qaic](set-device-settings-qaic/index.md)
* [set-echo-off-win](set-echo-off-win/index.md)
* [set-performance-mode](set-performance-mode/index.md)
* [set-sqlite-dir](set-sqlite-dir/index.md)
* [tar-my-folder](tar-my-folder/index.md)
